@@ -1,4 +1,5 @@
 # 2013-01-08: now much faster since we only mix/clean data with > 1 color / horizon
+# consider mixing and returning closest Munsell color... does this make sense in RGB color space?
 
 # results can be referenced via phiid (horizon-level ID)
 get_colors_from_NASIS_db <- function() {
@@ -27,8 +28,8 @@ pedon_View_1 INNER JOIN phorizon_View_1 ON pedon_View_1.peiid = phorizon_View_1.
 	d <- cbind(d, d.rgb)
 	
 	# split into dry / moist
-	dry.colors <- subset(d, d$colormoistst == 1)
-	moist.colors <- subset(d, d$colormoistst == 2)
+	dry.colors <- d[which(d$colormoistst == 1), ]
+	moist.colors <- d[which(d$colormoistst == 2), ]
 	
 	# split-out those data that need color mixing:
 	dry.to.mix <- names(which(table(dry.colors$phiid) > 1))
